| Block-class | R Documentation |
Class used within the package to keep the structure and information about the generated blocks.
featuresa vector of numeric which contains the indices of the block.
explained_variancea numeric which contains the variance explained of the blocks variables based on the whole data set.
is_valida logical which indicates if the block structure is valid.
ev_influenceda vector of numeric which contains the indices of the eigenvectors influenced by this block.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.